<?php

namespace Litecms\Bet\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Bet\Models\Bets;

class BetsPolicy
{

    /**
     * Determine if the given user can view the bets.
     *
     * @param UserPolicy $user
     * @param Bets $bets
     *
     * @return bool
     */
    public function view(UserPolicy $user, Bets $bets)
    {
        if ($user->canDo('bet.bets.view') && $user->isAdmin()) {
            return true;
        }

        return $bets->user_id == user_id() && $bets->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bets.
     *
     * @param UserPolicy $user
     * @param Bets $bets
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('bet.bets.create');
    }

    /**
     * Determine if the given user can update the given bets.
     *
     * @param UserPolicy $user
     * @param Bets $bets
     *
     * @return bool
     */
    public function update(UserPolicy $user, Bets $bets)
    {
        if ($user->canDo('bet.bets.edit') && $user->isAdmin()) {
            return true;
        }

        return $bets->user_id == user_id() && $bets->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bets.
     *
     * @param UserPolicy $user
     * @param Bets $bets
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Bets $bets)
    {
        return $bets->user_id == user_id() && $bets->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bets.
     *
     * @param UserPolicy $user
     * @param Bets $bets
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Bets $bets)
    {
        if ($user->canDo('bet.bets.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bets.
     *
     * @param UserPolicy $user
     * @param Bets $bets
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Bets $bets)
    {
        if ($user->canDo('bet.bets.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
